@@ -123,6 +123,7 @@ STRUCTURE = Nav(
                 Nav("Sai, Master Thopterist", cat="controle"),
                 Nav("Saskia the Unyielding", cat="agro"),
                 Nav("❌ Shorikai, Genesis Engine", cat="ban"),
+                Nav("Soul of Windgrace", cat="controle"),
                 Nav("Sygg, River Cutthroat", cat="controle"),
                 Nav("Sythis, Harvest's Hand", cat="combo"),
                 Nav("The Beamtown Bullies", cat="combo"),
@@ -168,6 +169,7 @@ STRUCTURE = Nav(
                 Nav("28. Azusa vs Elmar-Hargilde", cat="21-30"),
                 Nav("29. Erinis vs Raff", cat="21-30"),
                 Nav("30. Gut vs Yoshimaru", cat="21-30"),
+                Nav("31. Raffine vs Soul of Windgrace", cat="31-40"),
             ],
         ),
         Nav(
